pub struct RedbDatabase { /* private fields */ }Expand description
Redb backend implementation.
Redb is a simple, portable, high-performance, ACID, embedded key-value database. A CrepeDB backend implementation using redb.
This struct wraps a redb Database and implements the CrepeDB Backend trait,
allowing redb to be used as the storage engine for CrepeDB.
Implementations
Sourceimpl RedbDatabase
impl RedbDatabase
Sourcepub fn open_or_create(path: impl AsRef<Path>) -> Result<RedbDatabase, Error>
pub fn open_or_create(path: impl AsRef<Path>) -> Result<RedbDatabase, Error>
Open or create a persistent redb database at the specified path.
If the database doesn’t exist, it will be created. If it exists, it will be opened.
Arguments
path- The file path where the database should be stored
Errors
Returns an error if the database cannot be created or opened.
Example
ⓘ
let db = RedbDatabase::open_or_create("mydb.redb")?;Sourcepub fn memory() -> Result<RedbDatabase, Error>
pub fn memory() -> Result<RedbDatabase, Error>
Sourcepub fn into_inner(self) -> Database
pub fn into_inner(self) -> Database
Consume the database and return the underlying redb database.